
arch=`uname -m`;
platform=`uname -s`;

show_messages () {
	if tty -s; then
		echo $1
	fi
	echo "script `date`:- $1" >>$MSHOME/console.log;
}

if [ ! "$2" = 'nosu' ]; then 
	if id | grep "^uid=0(" >/dev/null 2>&1
		then # user IS superuser
       			show_messages "Commencing MyConnection Server service as root."
		else
       			show_messages "MyConnection Server needs to be run as root.";
        		if [ "$platform" = 'Darwin' ]; then
        			show_messages "run it with 'sudo sh mcs.sh $1'."
				fi
       		exit 1;
	fi
fi


USAGE="Usage: mcs.sh { start | stop | status } "

stop_process () {
        processgone=0;
        cd $MSHOME;
        for count in 1 2 3 4 5 6 7 8; do
                show_messages "Posting shutdown file to MyConnection Server service."
                touch mcs.shutdown;
                sleep 3;
		if [ "$platform" = 'Linux' ]; then
				pslist=`/bin/ps -elf | grep jar`
		elif [ "$platform" = 'Darwin' ]; then
        			pslist=`/bin/ps ajxw | grep jar`
		elif [ "$platform" = 'FreeBSD' ]; then
				pslist=`/bin/ps ajxw | grep jar`
		else
				pslist=`/bin/ps -ef | grep jar`
		fi
				
		if [ "$platform" = 'Linux' ]; then
                        PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $4 }'`
                else
                        PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $2 }'`
                fi
                if [ -z "$PID" ]; then
                        processgone=1;
                        break;
                fi
        done

        if [ $processgone -ne 1 ]; then
		if [ "$platform" = 'Linux' ]; then
				pslist=`/bin/ps -elf | grep jar`
		elif [ "$platform" = 'Darwin' ]; then
        			pslist=`/bin/ps ajxw | grep jar`
		elif [ "$platform" = 'FreeBSD' ]; then
				pslist=`/bin/ps ajxw | grep jar`
		else
				pslist=`/bin/ps -ef | grep jar`
		fi
			
            show_messages "Attempting to stop MyConnection Server service."
			if [ "$platform" = 'Linux' ]; then
        			PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $4 }'`
        	else
        			PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $2 }'`
        	fi

            if [ ! -z "$PID" ]; then
            		show_messages "Attempting to stop $1 with PID: $PID.";
            		/bin/kill ${PID} > /dev/null 2>&1;
            fi
        fi
}

status_process () {
	if [ "$platform" = 'Linux' ]; then
		pslist=`/bin/ps -elf | grep jar`
	elif [ "$platform" = 'Darwin' ]; then
        	pslist=`/bin/ps ajxw | grep jar`
	elif [ "$platform" = 'FreeBSD' ]; then
		pslist=`/bin/ps ajxw | grep jar`
	else
		pslist=`/bin/ps -ef | grep jar`
	fi

	show_messages "Checking for running MyConnection Server service."

	if [ "$platform" = 'Linux' ]; then
		PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $4 }'`;
	else
		PID=`echo "$pslist" | grep $1 | grep -v grep | awk '{ print $2 }'`;
	fi

	if [ ! -z "$PID" ]; then
		show_messages "MyConnection Server process $1 running with PID: $PID.";
	else
		show_messages "Unable to detect the MyConnection Server process running.";
		show_messages "Confirm that you have attempted to start it,";
	fi
}

start_process () {
	# Make sure the path is mounted
	if [ ! -f $MSHOME/$1 ]; then
        	show_messages "Unable to find the mss jar file in directory $MSHOME.";
			show_messages "Please check that MSHOME is set correctly in this script.";
        	exit;	
	fi

	# If there is a mcs.tar present someone has untared an upgrade but not done a mcs_configure.sh
	if [ -f $MSHOME/mcs.tar ]; then
        	show_messages "A mcs.tar is present, running configure.";
			sh mcs_configure.sh;
        	exit;
	fi

	testjava=`which java 2>/dev/null`
	if test -f "$testjava"; then
		show_messages " ";
        show_messages "Found a Java in $testjava, continuing.";
		show_messages " ";
	else
		show_messages "MyConnection Server requires a Java VM, but was unable to find one installed.";
		show_messages " ";
		show_messages "Please visit http://java.oracle.com to download and install one.";
		show_messages "After you have installed a JVM, try this script again.";
		show_messages " ";
		show_messages "If you are confident that you have one installed, please review the";
		show_messages "'PATH' variable in this script to confirm that it can find a /directory/bin/java installed.";
        exit 1;
	fi

	cd $MSHOME;
	testjvm=`java -classpath . TestJVM 2>/dev/null | awk '{ print $1 }'`;
	if [ "$testjvm" != 'Correct' ]; then
		show_messages "Current Oracle JRE JVMs recommended as best practice, Open JRE/JDK releases are supported";
		show_messages "noting problem resolutions may result in meeting best practice requirements.";
		show_messages "Please visit http://www.myconnectionserver.com/javasupport/jre.html";
		show_messages " ";
	fi

    testjvm=`java -classpath . TestJVM 2>/dev/null | awk '{ print $3 }'`;
    jvmram=`java -classpath . TestJVM 2>/dev/null | awk '{ print $4 }'`;
    if [ "$platform" = 'FreeBSD' ]; then
        if [ "$testjvm" = "64" ]; then
           cp -f libmswin32v15-freebsd-64bit.so libmswin32v15.so;
           show_messages "Copying FreeBSD 64bit shared library live";
        else
           cp -f libmswin32v15-freebsd-32bit.so libmswin32v15.so;
           show_messages "Copying FreeBSD 32bit shared library live";
        fi
    elif [ "$platform" = 'Darwin' ]; then
           cp -f libmswin32v15-osx.jnilib libmswin32v15.jnilib;
           show_messages "Copying OS X shared library live";
    elif [ "$platform" = 'SunOS' ]; then
        if [ "$testjvm" = "64" ]; then
        	# On x86 64bit OS, the JVM is still 32 bit (On Solaris 10. Oct 2012)
	   		if [ "$arch" = 'i86pc' ]; then 
              # cp -f libmswin32v15-solaris86-64bit.so libmswin32v15.so;
              show_messages "Please contact Visualware support because on x86 64bit OS the JVM is expected to be 32bit and not 64bit";
	   		else
              cp -f libmswin32v15-solaris-64bit.so libmswin32v15.so;
              show_messages "Copying Solaris Sparc 64bit shared library live";
           fi
        else
	   if [ "$arch" = 'i86pc' ]; then 
              cp -f libmswin32v15-solaris86-32bit.so libmswin32v15.so;
              show_messages "Copying Solaris x86 32bit shared library live";
	   		else
              cp -f libmswin32v15-solaris-32bit.so libmswin32v15.so;
              show_messages "Copying Solaris Sparc 32bit shared library live";
 	   		fi
        fi
    elif [ "$platform" = 'Linux' ]; then
         if [ "$testjvm" = "64" ]; then
            cp -f libmswin32v15-linux-64bit.so libmswin32v15.so;
            show_messages "Copying Linux 64bit shared library live";
         else
            cp -f libmswin32v15-linux-32bit.so libmswin32v15.so;
            show_messages "Copying Linux 32bit shared library live";
         fi
    fi

	if [ -s $MSHOME/$1 ]; then
		show_messages "MyConnection Server service starting.";
          	# for some solaris add 'nohup' to the start of the next line starting java
          	java -Djava.library.path=. -Djava.awt.headless=true -Xmx${jvmram}m -jar $1 -classpath . Boot -nogui &
	else
		show_messages "Unable to find or execute MyConnection Server ($1) service.";
	fi
}

# Check arguments started with
if [ "$1" = 'help' ]; then
        show_messages $USAGE;
        exit 1;
fi

cd $MSHOME;
# Warning more than one jar in the directory causes problems
dat=`ls *-mcs.jar`;

# Check arguments started with
if [ ! "$1" = 'stop' ] && [ ! "$1" = 'start' ] && [ ! "$1" = 'status' ]; then
	show_messages "Assuming start";
	start_process $dat;
	show_messages "  ";
	show_messages "To stop MyConnection Server, type 'sh $MSHOME/mcs.sh stop'.";
	show_messages "  ";
    exit 1;
fi

case "$1" in
'start')
	start_process $dat
	;;
'status')
        status_process $dat
        ;;
'stop')
        stop_process $dat
        ;;
*)
        show_messages $USAGE
        ;;
esac
exit 0;